# Generated by Django 4.2.20 on 2025-04-12 09:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('metaauth', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='token',
            name='external_id',
            field=models.CharField(default='1', max_length=255),
        ),
        migrations.AlterField(
            model_name='token',
            name='token',
            field=models.CharField(),
        ),
    ]
